@@ -20,7 +20,8 @@ impl From<Ipv4Addr> for in_addr {
 }
 
 #[derive(Copy, Clone, Debug)]
-#[repr(align(4))]
+#[cfg_attr(target_os = "windows", repr(align(2)))]
+#[cfg_attr(not(target_os = "windows"), repr(align(4)))]
 #[repr(C)]
 pub struct in6_addr {
     pub s6_addr: [u8; 16],
@@ -133,6 +134,7 @@ pub struct SlirpConfig {
     pub outbound_addr: *const sockaddr_in,
     pub outbound_addr6: *const sockaddr_in6,
     pub disable_dns: bool,
+    pub disable_dhcp: bool,
 }
 
 extern "C" {
